// Namespace for utility functions
var utils = {};

utils.is_touch_enabled = function () {"use strict"
  return ( 'ontouchstart' in window ) ||
    ( navigator.maxTouchPoints > 0 ) ||
    ( navigator.msMaxTouchPoints > 0 );
}

utils.setCookie = function (cookieName,cookieValue,nDays) {"use strict";
  var today = new Date();
  var expire = new Date();
  if (nDays==null || nDays==0) nDays=1;
  expire.setTime(today.getTime() + 60000*60*24*nDays);
  document.cookie = cookieName+"="+escape(cookieValue) + ";expires="+expire.toGMTString();
  //console.log(expire.toGMTString());
}

utils.getCookie = function (cookieName) {"use strict";
  var theCookie=" "+document.cookie;
  var ind=theCookie.indexOf(" "+cookieName+"=");
  if (ind==-1) ind=theCookie.indexOf(";"+cookieName+"=");
  if (ind==-1 || cookieName=="") return "";
  var ind1=theCookie.indexOf(";",ind+1);
  if (ind1==-1) ind1=theCookie.length;
  return decodeURIComponent(theCookie.substring(ind+cookieName.length+2,ind1));
}

// Namespace for intro functions
var intro = {};

intro.runIntro = function () {"use strict";

  if( utils.is_touch_enabled() || utils.getCookie('skipIntro') ){
    document.documentElement.classList.remove('intro');
  } else {
    intro = document.getElementById("intro");
    if(XMLHttpRequest) var x = new XMLHttpRequest();
    else var x = new ActiveXObject("Microsoft.XMLHTTP");
    x.open("GET", "./_inc/intro.php", true);
    x.send();
    x.onreadystatechange = function(){
      if(x.readyState == 4){
        if(x.status == 200){
          intro.innerHTML = x.responseText;
          const video = document.querySelector('#intro video');
          video.onended = (event) => {
            document.documentElement.classList.remove('intro');
            //console.log('Video stopped either because 1) it was over, or 2) no further data is available.');
          };
          utils.setCookie('skipIntro', 'true', 3);
        } else {
          intro.innerHTML = "Error loading document";
        }
      }
    }
  }
}

// Namespace for keyart functions
var keyart = {};

keyart.kids = document.getElementById("kids");

keyart.loadKids = function () {"use strict";
  function loadKids(){
    keyart.kids.innerHTML = '<div id="kid1" class="w100 kid"></div><div id="kid2" class="w100 kid"></div><div id="kid3" class="w100 kid"></div><div id="kid4" class="w100 kid"></div>';
    //keyart.kids();
    setTimeout(function(){
      keyart.setObserver();
      //console.log('setObserver called');
    },500);
    //console.log('kids loaded');
    window.removeEventListener("scroll", loadKids, { passive: true });
  }
  window.addEventListener("scroll", loadKids, { passive: true });
  //console.log('scroll listener added');
}

keyart.setObserver = function () {"use strict";
  // console.log('setObserver')
  let options = {
    rootMargin: '0px',
    threshold: 1
  }
  const intersectionCallback = (entries, observer) => {
    entries.forEach(entry => {
      // you can find out easily if target is intersecting by inspecting `isIntersecting` property
      if (entry.isIntersecting) {
        var kids = document.querySelectorAll('.kid');
        for (var i = 0; i < kids.length; i++) {
            kids[i].classList.add('animate');
        }
        //console.log('kids animating');
      } else {
        var kids = document.querySelectorAll('.kid');
        for (var i = 0; i < kids.length; i++) {
            kids[i].classList.remove('animate');
        }
      }
    });
  }
  let observer = new IntersectionObserver(intersectionCallback, options);
  let target = document.querySelector('#trigger');
  observer.observe(target);
}

keyart.animateKids = function () {"use strict";
  //console.log('animate kids');
  var kids = document.querySelectorAll('.kid');
  for (var i = 0; i < kids.length; i++) {
      kids[i].classList.add('intersect');
  }
}

//Namespace for team functions
var team = {};

team.bioindex = 0;
team.bios = [];

team.loadBios = function (page) {"use strict";
  // Reac Cast & Creative Bios into array
  var request = new XMLHttpRequest();

  request.open('GET', page, true);
  
  request.onload = function() {
    if (request.status >= 200 && request.status < 400) {
      var resp = request.responseText;
      var el = document.createElement( 'html' );
      el.innerHTML = resp;
      // Get all members as a NodeList
      var members = el.querySelectorAll('.member');
      // Convert members NodeList to an array
      //console.log(members.length);
      team.bios = Array.from(members);
      //console.log(team.bios);
    }
  };
  request.send();

  const overlayInner = document.querySelector('#overlay-inner');

  ['click','ontouchstart'].forEach( function(e) {
    document.addEventListener(e, function(e){
      if( e.target.classList.contains('next') ) {
        team.bioIndex++;
        overlayInner.classList.remove('show');
        setTimeout(function(){
          overlayInner.innerHTML = team.bios[team.bioIndex].outerHTML;
          overlayInner.querySelector('.headshot').classList.add('open');
          overlayInner.classList.add('show');
        },100);
        setTimeout(function(){
          overlayInner.querySelector('.headshot').classList.remove('open');
        },1200);
      } else if(e.target.classList.contains('prev')) {
        team.bioIndex--;
        overlayInner.classList.remove('show');
        setTimeout(function(){
          overlayInner.innerHTML = team.bios[team.bioIndex].outerHTML;
          overlayInner.querySelector('.headshot').classList.add('open');
          overlayInner.classList.add('show');
        },100);
        setTimeout(function(){
          overlayInner.querySelector('.headshot').classList.remove('open');
        },1200);
      } else if(e.target.classList.contains('close')) {
        overlayInner.classList.remove('show');
        document.documentElement.classList.remove('overlay-open');
      } else if(e.target.classList.contains('member')) {
        var child = e.target;
        var parent = child.parentNode;
        var index = Array.prototype.indexOf.call(parent.children, child);
        team.bioIndex = index;
        document.documentElement.classList.add('overlay-open');
        setTimeout(function(){
          overlayInner.innerHTML = team.bios[team.bioIndex].outerHTML;
          overlayInner.querySelector('.headshot').classList.add('open');
          overlayInner.classList.add('show');
        },100);
        setTimeout(function(){
          overlayInner.querySelector('.headshot').classList.remove('open');
        },1200);
      }

      if(team.bioIndex == (team.bios.length - 1) ){
        document.querySelector('#overlay .next').style.display = 'none';
      } else {
        document.querySelector('#overlay .next').style.display = 'block';
      }

      if(team.bioIndex == 0 ){
        document.querySelector('#overlay .prev').style.display = 'none';
      } else {
        document.querySelector('#overlay .prev').style.display = 'block';
      }

    }, false);
  });
};

window.addEventListener('load', () => {
  document.documentElement.classList.add('page-loaded');

  // code here
  team.loadBios('cast.html');
  intro.runIntro();
  keyart.loadKids();

 /*
     function fireModal() {
       $("#popup").show();
       $("#popup-bg").show();
     }
 
   /*  setTimeout(function() {
       fireModal();
     }, 1000); *
 
     $(document).on( "click",".close-popup", function(e) {
       e.preventDefault();
       $("#popup").fadeOut();
       $("#popup-bg").fadeOut();
     });
 
     $(document).on( "click","#popup-bg", function(e) {
       e.preventDefault();
       $("#popup").fadeOut();
       $("#popup-bg").fadeOut();
     });*/


});